import React from 'react';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { LabelProps } from './Label';
import { HelperTextProps } from './HelperText';
import { ValidationMessageProps } from './ValidationMessage';
export declare type VerticalFormFieldProps = PropsWithMetadata<{
    children: React.ReactNode;
    /**
     * Class name that will be applied to the element
     */
    className?: string;
    /**
     * Label for the input field
     */
    label: LabelProps['label'];
    /**
     * Specify which HTML element the Label is for
     */
    htmlFor?: LabelProps['htmlFor'];
    /**
     * The content to be displayed in the tooltip pop-out
     */
    labelTooltipContent?: LabelProps['tooltipContent'];
    /**
     * How quickly to hide the tooltip
     */
    labelTooltipMouseOutDelay?: LabelProps['tooltipMouseOutDelay'];
    /**
     * The text that will be displayed as a secondary label
     */
    helperText?: HelperTextProps['text'];
    /**
     * The grayed out, additional to the `helperText` information.
     */
    hintText?: HelperTextProps['hintText'];
    /**
     * An array of objects that represent different validation states
     */
    validations?: Array<Omit<ValidationMessageProps, 'className'>>;
}>;
declare const VerticalFormField: ({ className, children, label, htmlFor, labelTooltipContent, labelTooltipMouseOutDelay, helperText, hintText, metadata, validations, }: VerticalFormFieldProps) => JSX.Element;
export default VerticalFormField;
